@@ -48,7 +48,7 @@ sub init {
     # In general subclasses should Just Work.
 
     # need to read this first, since the later opts depend on it
-    $self->copy_option($opts, 'use_test_urls');
+    $self->copy_option($opts, 'use_test_urls') if defined $opts->{use_test_urls};
 
     # These are required, NOT provided by this class, but are by subclasses.
     for my $field (qw(token_endpoint authorization_endpoint)) {
